#!/bin/bash

echo -e "XXXXXXX\tO1CCOCC1.OC1(OOC(C1)(C(F)(F)F)O)C(F)(F)F\tC([C@@]1(C[C@@](C(F)(F)F)(OO1)O)O)(F)(F)F.C1COCCO1.C([C@]1(C[C@](C(F)(F)F)(OO1)O)O)(F)(F)F.C1COCCO1" \
    | smi_isomorphism
